<?php

// Example PHP class for making Grade.us API calls

class GradeUsApi {

  const URL = 'https://www.grade.us/api/v1';

  function __construct($profile_id, $token, $secret = NULL) {
    $this->profile_id = $profile_id;
    $this->token = $token;
    $this->secret = $secret;
  }
  
  function doRequest($endpoint, $data, $method, $signRequest = false) {
    
    // Use this profile ID:
    $data['profile_id'] = $this->profile_id;
    
    // Init CURL:
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_TIMEOUT, 30);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    
    // Add auth token:
    curl_setopt($ch, CURLOPT_HTTPHEADER, array('Accept: application/json', 'Authorization: Token token='.$this->token));
    
    // Sign request if necessary:
    if ($signRequest) {
      /* -------------------------------------------------------
        Sign a request by including a hash of the request data
        serialized, encoded and in key order
      ------------------------------------------------------- */
      ksort($data);
      $request_data = array();
      foreach ($data as $key => $value) {
        $key = str_replace("%7E", "~", urlencode($key));
        $value = str_replace("%7E", "~", urlencode($value));
        $request_data[] = $key . '=' . $value;
      }
      $signed_str = implode('&', $request_data);
      $signature = base64_encode(hash_hmac('sha256', $signed_str, $this->secret, true));
      $data['hash'] = $signature;
    }
    
    // Build the query:
    $query = '';
    switch($method) {
      case 'GET':
        $query = '/' . $endpoint . '?' . http_build_query($data);
        break;
      case 'POST':
        $query = '/' . $endpoint;
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
        break;
    }
    // Strip double slashes and setup URL:
    while (strpos($query, '//') > -1) {
      $query = str_replace('//', '/', $query);
    }
    curl_setopt($ch, CURLOPT_URL, self::URL.$query);

    // Execute CURL and close:
    $response = curl_exec($ch);
    curl_close($ch);

    // Decode JSON and return:
    return json_decode($response, true);

  }
    
}


?>